==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGridToolbarContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebGridToolbarContentDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarContentDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarContentDescriptionMetadata.a == null) {
                WebGridToolbarContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarContentDescriptionMetadata.c(WebGridToolbarContentDescriptionMetadata.a);
            }
            if (a.j(WebGridToolbarContentDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridToolbarContentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridToolbarContent");
            a.item("__tagNameWC", "String:igc-grid-toolbar-content");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("Name", "String");
            WebGridToolbarContentDescriptionMetadata.e(a);
        }
        static d(a) {
            WebGridToolbarContentDescriptionMetadata.b(a);
            a.z("WebGridToolbarContent", WebGridToolbarContentDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__tagNameWCSubstitutable", "String:igc-grid-toolbar-actions,igc-grid-toolbar-title");
        }
    }
    WebGridToolbarContentDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarContentDescriptionMetadata, 'WebGridToolbarContentDescriptionMetadata');
    WebGridToolbarContentDescriptionMetadata.a = null;
    return WebGridToolbarContentDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridToolbarContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebGridToolbarContentDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarContentDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarContentDescriptionMetadata.a == null) {
                WebGridToolbarContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarContentDescriptionMetadata.c(WebGridToolbarContentDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarContentDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridToolbarContentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridToolbarContent");
            a.item("__tagNameWC", "String:igc-grid-toolbar-content");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("Name", "String");
            WebGridToolbarContentDescriptionMetadata.e(a);
        }
        static d(a) {
            WebGridToolbarContentDescriptionMetadata.b(a);
            a.ab("WebGridToolbarContent", WebGridToolbarContentDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__tagNameWCSubstitutable", "String:igc-grid-toolbar-actions,igc-grid-toolbar-title");
        }
    }
    WebGridToolbarContentDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarContentDescriptionMetadata, 'WebGridToolbarContentDescriptionMetadata');
    WebGridToolbarContentDescriptionMetadata.a = null;
    return WebGridToolbarContentDescriptionMetadata;
})();
